Metadata (PEP 621) :mod:`partis.pyproj.pkginfo`
===============================================

.. currentmodule:: partis.pyproj.pkginfo

PkgInfo
-------

.. autoclass:: PkgInfo


PkgInfoReq
----------

.. autoclass:: PkgInfoReq


PkgInfoURL
----------

.. autoclass:: PkgInfoURL


PkgInfoAuthor
-------------

.. autoclass:: PkgInfoAuthor
